@@ -9,7 +9,7 @@ test_that("galah_filter gives an error for single equals sign", {
 })
 
 test_that("galah_filter works with assertions", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   count_all <- atlas_counts() |>
     pull(count)
   count_invalid_spp <- galah_call() |>
@@ -30,7 +30,7 @@ test_that("galah_filter works with assertions", {
 })
 
 test_that("galah_filter handles multiple assertions", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   # OR statements
   all_records <- atlas_counts() |>
     pull(count)
@@ -76,7 +76,7 @@ test_that("galah_filter handles multiple assertions", {
 })
 
 test_that("galah_filter handles assertions and taxa", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   problem_families <- galah_call() |>
     filter(assertions == "INVALID_SCIENTIFIC_NAME") |>
     group_by(family) |>
@@ -134,7 +134,7 @@ test_that("galah_filter handles OR statements", {
   filters <- galah_filter(year == 2010 | year == 2020)
   expect_equal(nrow(filters), 1)
   expect_equal(filters$value, "2010|2020")
-  expect_equal(filters$query, "((year:\"2010\") OR (year:\"2020\"))")
+  expect_equal(filters$query, "(year:\"2010\") OR (year:\"2020\")")
 })
 
 test_that("galah_filter handles OR statements", {   
@@ -142,7 +142,7 @@ test_that("galah_filter handles OR statements", {
                           raw_scientificName == "Litoria peronii")
   expect_equal(nrow(filters), 1)
   expect_equal(filters$query, 
-               "((raw_scientificName:\"Litoria jervisiensis\") OR (raw_scientificName:\"Litoria peronii\"))")
+               "(raw_scientificName:\"Litoria jervisiensis\") OR (raw_scientificName:\"Litoria peronii\")")
 })
 
 test_that("galah_filter works with 3 OR statements", {
@@ -152,7 +152,7 @@ test_that("galah_filter works with 3 OR statements", {
   expect_equal(nrow(filters), 1)
   expect_equal(filters$value, "HumanObservation|MachineObservation|PreservedSpecimen")
   expect_equal(filters$query, 
-               "((basisOfRecord:\"HumanObservation\") OR (basisOfRecord:\"MachineObservation\") OR (basisOfRecord:\"PreservedSpecimen\"))")
+               "(basisOfRecord:\"HumanObservation\") OR (basisOfRecord:\"MachineObservation\") OR (basisOfRecord:\"PreservedSpecimen\")")
 })
 
 test_that("galah_filter handles exclusion", {   
@@ -220,7 +220,7 @@ test_that("galah_filter returns error when equations are passed as a string", {
 # expect_true(grepl("2010", filters$query))
 
 test_that("galah_filter handles taxonomic queries", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   filters <- galah_filter(taxonConceptID == search_taxa("Animalia")$taxon_concept_id)
   expect_equal(nrow(filters), 1)
   expect_false(grepl("search_taxa", filters$query))
@@ -235,7 +235,7 @@ test_that("galah_filter handles taxonomic queries when passed as a string", {
 })
 
 test_that("galah_filter handles taxonomic exclusions", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   filters <- galah_filter(
     taxonConceptID == search_taxa("Animalia")$taxon_concept_id,
     taxonConceptID != search_taxa("Chordata")$taxon_concept_id)
@@ -244,7 +244,7 @@ test_that("galah_filter handles taxonomic exclusions", {
 })
 
 test_that("galah_filter handles lsid as an input", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   ids <- c("https://biodiversity.org.au/afd/taxa/0df99ece-1982-4605-a2b3-4fcb7660ee2b",
            "https://id.biodiversity.org.au/node/apni/2910467",
            "https://id.biodiversity.org.au/node/apni/291047") # wrong id
@@ -266,7 +266,7 @@ test_that("galah_filter handles lsid as an input", {
 
 test_that("galah_filter handles different fields separated by OR", {
   filters <- galah_filter(phylum == "Chordata" | kingdom == "Plantae")
-  expect_equal(filters$query, "((phylum:\"Chordata\") OR (kingdom:\"Plantae\"))")
+  expect_equal(filters$query, "(phylum:\"Chordata\") OR (kingdom:\"Plantae\")")
 })
 
 test_that("galah_filter fails when given invalid AND syntax", {
@@ -301,12 +301,12 @@ test_that("galah_filter handles %in% even with multiple filters", {
   filter_multiple <- galah_filter(year %in% list_of_years, cl22 == "Tasmania")
   expect_equal(nrow(filter_single), 1)
   expect_equal(nrow(filter_multiple), 2)
-  expect_equal("((year:\"2020\") OR (year:\"2021\") OR (year:\"2022\"))", filter_single$query[[1]])
+  expect_equal("(year:\"2020\") OR (year:\"2021\") OR (year:\"2022\")", filter_single$query[[1]])
   expect_equal("((year:\"2020\") OR (year:\"2021\") OR (year:\"2022\"))", filter_multiple$query[[1]])
 })
 
 test_that("galah_filter parses fields correctly with is.na()", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   expect_no_error(galah_call() |> 
                     galah_filter(is.na(decimalLongitude)) |> 
                     atlas_counts()
@@ -335,7 +335,7 @@ test_that("galah_filter parses fields correctly with is.na()", {
 })
 
 test_that("`galah_filter()` handles apostrophes (') correctly", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   names <- c("Australia's Virtual Herbarium", 
              "iNaturalist observations",
              "iNaturalist research-grade observations")
@@ -345,11 +345,11 @@ test_that("`galah_filter()` handles apostrophes (') correctly", {
     atlas_counts()
   expect_equal(nrow(query), 1) # returns result
   expect_gte(query$count[1], 1)
-  expect_match(filter, "\\(\\(datasetName:\\\"Australia's Virtual Herbarium\\\"\\)")
+  expect_match(filter, "\\(datasetName:\\\"Australia's Virtual Herbarium\\\"")
 })
 
 test_that("`galah_filter()` handles multiple values with brackets correctly", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   filter <- galah_filter(
     scientificName == c("Aviceda (Aviceda) subcristata", 
                         "Todiramphus (Todiramphus) sanctus"))$query
@@ -359,11 +359,19 @@ test_that("`galah_filter()` handles multiple values with brackets correctly", {
     atlas_counts()
   expect_equal(nrow(query), 1) # returns result
   expect_gte(query$count[1], 1)
-  expect_match(filter, "\\(\\(scientificName:\\\"Aviceda \\(Aviceda\\) subcristata\\\"\\)")
+  expect_match(filter, "\\(scientificName:\\\"Aviceda \\(Aviceda\\) subcristata\\\"\\)")
+})
+
+test_that("galah_filter builds correct query with `!`, `%in%`, `c()` and `identify()`", {    
+  ibra_subset <- c("Brigalow Belt North", "Brigalow Belt South", "Central Mackay Coast")
+  query <- request_data(type = "occurrences-count") |> 
+    identify("Crinia signifera") |>
+    filter(!cl1048 %in% ibra_subset)
+  expect_equal(query$filter$query, c("-(cl1048:\"Brigalow Belt North\") OR -(cl1048:\"Brigalow Belt South\") OR -(cl1048:\"Central Mackay Coast\")"))
 })
 
 test_that("`galah_filter()` accepts {{}} on lhs of formula", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   field <- "species"
   result <- galah_call() |>
     galah_filter({{field}} == "Eolophus roseicapilla") |>
@@ -379,7 +387,7 @@ test_that("`galah_filter()` accepts {{}} on lhs of formula", {
 })
 
 test_that("`group_by()` works when > 1 `filter()`", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   chosen_species <- c("Eolophus roseicapilla", "Platycercus elegans")
   x <- request_data() |>
     filter(species == chosen_species) |>
@@ -446,4 +454,4 @@ test_that("galah_filter handles `type = 'files'` correctly", {
   expect_equal(y$filter, x)
   z <- request_files() |> filter(media == x)
   expect_equal(y, z)
-})
\ No newline at end of file
+})
